@@ -9,6 +9,9 @@ class Store:
   """
   def __init__(self):
     self.storage = SimpleNamespace()
+    self.step_item = None
+    self.action_item = None
+    self.method_item = None
 
   def put(self, prop, value):
     """Store the ``prop`` variable and its value.
@@ -41,3 +44,6 @@ class Store:
     """Clear the Store content.
     """
     self.storage = SimpleNamespace()
+    self.step_item = None
+    self.action_item = None
+    self.method_item = None
