@@ -21,6 +21,9 @@ class Processor:
     if context.store.method_item is not None:
       pattern = re.compile(r"\$method_item\$")
       statement = re.sub(pattern, str(context.store.method_item), statement)
+    file_ptn = re.compile(r"\$file\$")
+    filepath = f"{context.workspace.workspace_path}/"
+    statement = re.sub(file_ptn, filepath, statement)
     return Parser().eval(statement)
 
   @staticmethod
@@ -38,4 +41,7 @@ class Processor:
     if context.store.method_item is not None:
       pattern = re.compile(r"\$method_item\$")
       value = re.sub(pattern, str(context.store.method_item), value)
+    file_ptn = re.compile(r"\$file\$")
+    filepath = f"{context.workspace.workspace_path}/"
+    value = re.sub(file_ptn, filepath, value)
     return Parser().literal_eval(value)
