@@ -35,7 +35,7 @@ class Workspace:
   def data_to_file(self, filename, data, mode="w",
                    encoding=None, offset=0, whence=0):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info("Saving file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    logging.info(f"Saving file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
     with open(filename, mode=mode, encoding=encoding) as datafile:
       datafile.seek(offset, whence)
       datafile.write(data)
@@ -43,14 +43,14 @@ class Workspace:
   def data_from_file(self, filename, length=None, mode="r",
                      encoding=None, offset=0, whence=0):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info("Reading file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    logging.info(f"Reading file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
     with open(filename, mode=mode, encoding=encoding) as datafile:
       datafile.seek(offset, whence)
       return datafile.read(length)
 
   def stream_from_file(self, filename, mode="r", encoding=None):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info("Getting bytestream: {filename} ({mode} / {encoding})")
+    logging.info(f"Getting bytestream: {filename} ({mode} / {encoding})")
     return open(filename, mode=mode, encoding=encoding)
 
   def delete(self):
